==> image-processing-1.3.1-sources.jar: org/openimaj/image/processing/algorithm/GammaCorrection.java <==
/**
 * Copyright (c) 2011, The University of Southampton and the individual contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 *
 *   *	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 *
 *   *	Neither the name of the University of Southampton nor the names of its
 * 	contributors may be used to endorse or promote products derived from this
 * 	software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openimaj.image.processing.algorithm;

import org.openimaj.image.processor.PixelProcessor;

/**
 * Class to perform Gamma correction on a grey-level image.
 * Grey levels are transformed such that I_new = I^Gamma for
 * Gamma > 0 and all pixels I. If Gamma == 0 then the transform
 * is I_new = log(I). 
 * 
 * @author Jonathon Hare (jsh2@ecs.soton.ac.uk)
 *
 */
public class GammaCorrection implements PixelProcessor<Float> {
	protected double gamma;
	
	/**
	 * Construct a GammaCorrection with the default gamma of 0.2
	 */
	public GammaCorrection() {
		this.gamma = 0.2; 
	}
	
	/**
	 * Construct a GammaCorrection with the given gamma
	 * @param gamma The gamma value to use
	 */
	public GammaCorrection(double gamma) {
		this.gamma = gamma; 
	}
	
	@Override
	public Float processPixel(Float pixel) {
		if (gamma == 0) {
			return (float) Math.log(pixel);
		}
		return (float) Math.pow(pixel, gamma);
	}
}

==> image-processing-1.3.5-sources.jar: org/openimaj/image/processing/algorithm/GammaCorrection.java <==
/**
 * Copyright (c) 2011, The University of Southampton and the individual contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 *
 *   *	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 *
 *   *	Neither the name of the University of Southampton nor the names of its
 * 	contributors may be used to endorse or promote products derived from this
 * 	software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openimaj.image.processing.algorithm;

import org.openimaj.image.processor.PixelProcessor;

/**
 * Class to perform Gamma correction on a grey-level image.
 * Grey levels are transformed such that I_new = I^Gamma for
 * Gamma &gt; 0 and all pixels I. If Gamma == 0 then the transform
 * is I_new = log(I). 
 * 
 * @author Jonathon Hare (jsh2@ecs.soton.ac.uk)
 *
 */
public class GammaCorrection implements PixelProcessor<Float> {
	protected double gamma;
	
	/**
	 * Construct a GammaCorrection with the default gamma of 0.2
	 */
	public GammaCorrection() {
		this.gamma = 0.2; 
	}
	
	/**
	 * Construct a GammaCorrection with the given gamma
	 * @param gamma The gamma value to use
	 */
	public GammaCorrection(double gamma) {
		this.gamma = gamma; 
	}
	
	@Override
	public Float processPixel(Float pixel) {
		if (gamma == 0) {
			return (float) Math.log(pixel);
		}
		return (float) Math.pow(pixel, gamma);
	}
}
